package de.fhhannover.inform.trust.ifmapj.messages;

import java.util.Collection;

import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;

/**
 * Interface to access {@link SearchResult} objects contained in a {@link PollResult}.
 * 
 * <b>Note:</b> All returned collections should be assumed to be unmodifiable.
 * 
 * @author aw
 *
 */
public interface PollResult {
	
	/**
	 * Get all {@link SearchResult} objects that were received after the initial
	 * poll has been sent to the MAPS.
	 * 
	 * @return an unmodifiable collection of {@link SearchResult} objects
	 */
	public Collection<SearchResult> getSearchResults();

	/**
	 * Get all {@link SearchResult} objects for new metadata that has been
	 * published to the MAPS since the last poll.
	 * 
	 * @return an unmodifiable collection of {@link SearchResult} objects
	 */
	public Collection<SearchResult> getUpdateResults();

	/**
	 * Get all {@link SearchResult} objects for metadata that has been
	 * deleted from the MAPS since the last poll.
	 * 
	 * @return an unmodifiable collection of {@link SearchResult} objects
	 */
	public Collection<SearchResult> getDeleteResults();

	/**
	 * Get all {@link SearchResult} objects for metadata that has been
	 * published to the MAPS by using the publish notify request since the last
	 * poll.
	 * 
	 * @return an unmodifiable collection of {@link SearchResult} objects
	 */
	public Collection<SearchResult> getNotifyResults();

	/**
	 * Get all {@link IfmapErrorResult} objects that indicate errors that
	 * occured since the last poll.
	 * 
	 * @return an unmodifiable collection of {@link IfmapErrorResult} objects
	 */
	public Collection<IfmapErrorResult> getErrorResults();
}
