package de.fhhannover.inform.trust.ifmapj.messages;

import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;

import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;

/**
 * Implementation of {@link PollResult}
 * 
 * @author aw
 *
 */
class PollResultImpl implements PollResult {
	
	private final Collection<SearchResult> mSearchResults;
	private final Collection<SearchResult> mUpdateResults;
	private final Collection<SearchResult> mDeleteResults;
	private final Collection<SearchResult> mNotifyResults;
	private final Collection<IfmapErrorResult> mErrorResults;
	
	PollResultImpl (
			Collection<SearchResult> sres, Collection<SearchResult> ures,
			Collection<SearchResult> dres, Collection<SearchResult> nres,
			Collection<IfmapErrorResult> eres) {
		
		if (sres == null || ures == null || dres == null || nres == null
				|| eres == null)
			throw new NullPointerException("result list is null");
			
		mSearchResults = new LinkedList<SearchResult>(sres);
		mUpdateResults = new LinkedList<SearchResult>(ures);
		mDeleteResults = new LinkedList<SearchResult>(dres);
		mNotifyResults = new LinkedList<SearchResult>(nres);
		mErrorResults = new LinkedList<IfmapErrorResult>(eres);
	}

	@Override
	public Collection<SearchResult> getSearchResults() {
		return Collections.unmodifiableCollection(mSearchResults);
	}

	@Override
	public Collection<SearchResult> getUpdateResults() {
		return Collections.unmodifiableCollection(mUpdateResults);
	}

	@Override
	public Collection<SearchResult> getDeleteResults() {
		return Collections.unmodifiableCollection(mDeleteResults);
	}

	@Override
	public Collection<SearchResult> getNotifyResults() {
		return Collections.unmodifiableCollection(mNotifyResults);
	}

	@Override
	public Collection<IfmapErrorResult> getErrorResults() {
		return Collections.unmodifiableCollection(mErrorResults);
	}
}
